Pure Storage Access — ucampurestorage 1.0.1 documentation

# Pure Storage Access

We need secrets to make API call.

    {
    "client_id": "25********************************0d",
    "key_id": "f**************************************d",
    "client_name": "apitest",
    "storage": "purestorage.cam.ac.uk",
    "user": "pureuser",
    "password": "********,
    "keyfile": "/tmp/fa2xprivate.pem"
    }

To generate necessay field mentioned above, we need to create user and API client.

STEP 1. Login to Pure storage URL > settings

STEP 2. Click on the “Access” tab

STEP 3. Click on the dots of User table and click create User

STEP 4. Input the required fields and create with role “Array Admin”.

This inputs will be utilized in secrets.json

  “user”: “**”, “password”: “******,

STEP 5. Click on the dots to create the API clients

STEP 6. Input the necessay field with role “Array Admin”.

This inputs will be utilized in secrets.json

  “client_id”: “25********************************0d”, “key_id”: “f**************************************d”, “client_name”: “apitest”,

NOTE: In the step6, public key must be added and private key will be utilized to make API Calls

  “keyfile”: “/tmp/fa2xprivate.pem”